# django-bigbuild

The open-source engine that powers bigbuilder, the Los Angeles Times Data Desk's system for publishing standalone pages at [latimes.com/projects/](http://www.latimes.com/projects/)

[![PyPI version](https://badge.fury.io/py/django-bigbuild.png)](http://badge.fury.io/py/django-bigbuild)
[![Build Status](https://travis-ci.org/datadesk/django-bigbuild.svg?branch=master)](https://travis-ci.org/datadesk/django-bigbuild)
[![Coverage Status](https://coveralls.io/repos/github/datadesk/django-bigbuild/badge.svg?branch=master)](https://coveralls.io/github/datadesk/django-bigbuild?branch=master)

## Quick links

Name | URL
:--- |:---
Documentation | [django-bigbuild.rtfd.io](http://django-bigbuild.rtfd.io)
Packaging | [pypi.python.org/pypi/django-bigbuild](https://pypi.python.org/pypi/django-bigbuild)
Build bot | [travis-ci.org/datadesk/django-bigbuild](https://travis-ci.org/datadesk/django-bigbuild/)
Coverage status | [coveralls.io/github/datadesk/django-bigbuild](https://coveralls.io/github/datadesk/django-bigbuild)
